package com.youjiayun.demo.entity.common;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.io.Serializable;

/**
 * @Author 涛涛
 * @Desc  api请求返回公共参数
 * @Date 2021-12-02 10:07 上午
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
public class ResultApiJson<T> implements Serializable {
    private static final long serialVersionUID = 783015033603078674L;
    private int code;
    private String msg;
    private T data;

    public ResultApiJson(ResultApiExportCode resultCode) {
        setResultCode(resultCode);
    }

    public ResultApiJson(int code, String msg) {
        this.code = code;
        this.msg = msg;
    }

    public ResultApiJson(ResultApiExportCode resultCode, T data) {
        setResultCode(resultCode);
        this.data = data;
    }

    public void setResultCode(ResultApiExportCode resultCode) {
        this.code = resultCode.getCode();
        this.msg = resultCode.getMsg();
    }


    public static ResultApiJson success() {
        ResultApiJson jsonResult = new ResultApiJson();
        jsonResult.setCode(ResultApiExportCode.SUCCESS.getCode());
        jsonResult.setMsg(ResultApiExportCode.SUCCESS.getMsg());
        return jsonResult;
    }

    public static ResultApiJson success(ResultApiExportCode code) {
        ResultApiJson jsonResult = new ResultApiJson();
        jsonResult.setCode(code.getCode());
        jsonResult.setMsg(code.getMsg());
        return jsonResult;
    }

    public static ResultApiJson successResult(Object data) {
        ResultApiJson jsonResult = new ResultApiJson();
        jsonResult.setCode(ResultApiExportCode.SUCCESS.getCode());
        jsonResult.setMsg(ResultApiExportCode.SUCCESS.getMsg());
        jsonResult.setData(data);
        return jsonResult;
    }

    public static ResultApiJson successMessage(String message) {
        ResultApiJson jsonResult = new ResultApiJson();
        jsonResult.setCode(ResultApiExportCode.SUCCESS.getCode());
        jsonResult.setMsg(message);
        return jsonResult;
    }

    public static ResultApiJson failure() {
        ResultApiJson jsonResult = new ResultApiJson();
        jsonResult.setCode(ResultApiExportCode.SERVER_ERROR.getCode());
        jsonResult.setMsg(ResultApiExportCode.SERVER_ERROR.getMsg());
        return jsonResult;
    }

    public static ResultApiJson failure(ResultApiExportCode code) {
        ResultApiJson jsonResult = new ResultApiJson();
        jsonResult.setCode(code.getCode());
        jsonResult.setMsg(code.getMsg());
        return jsonResult;
    }

    public static ResultApiJson failureMessage(String message, Object data) {
        ResultApiJson jsonResult = new ResultApiJson();
        jsonResult.setCode(ResultApiExportCode.SERVER_ERROR.getCode());
        jsonResult.setMsg(message);
        jsonResult.setData(data);
        return jsonResult;
    }


    public static ResultApiJson failureMessage(String message) {
        ResultApiJson jsonResult = new ResultApiJson();
        jsonResult.setCode(ResultApiExportCode.SERVER_ERROR.getCode());
        jsonResult.setMsg(message);
        return jsonResult;
    }

    @Override
    public String toString() {
        return "{" +
                "\"code\":" + code +
                ", \"msg\":\"" + msg + '\"' +
                ", \"data\":\"" + data + '\"'+
                '}';
    }


}

